@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2025 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -170,7 +170,7 @@ extern "C" {
 #define BRL_CMD_SWITCHVT_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT_NEXT)
 /** bring screen cursor to current line */
 #define BRL_CMD_CSRJMP_VERT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRJMP_VERT)
-/** insert clipboard text after screen cursor */
+/** insert the clipboard content before the screen cursor */
 #define BRL_CMD_PASTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE)
 /** restart braille driver */
 #define BRL_CMD_RESTARTBRL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RESTARTBRL)
@@ -290,7 +290,7 @@ extern "C" {
 #define BRL_CMD_HOST_COPY (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOST_COPY)
 /** cut selected text to host clipboard */
 #define BRL_CMD_HOST_CUT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOST_CUT)
-/** insert host clipboard text after screen cursor */
+/** insert the host clipboard text before the screen cursor */
 #define BRL_CMD_HOST_PASTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOST_PASTE)
 /** show the window title */
 #define BRL_CMD_GUI_TITLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_TITLE)
@@ -324,6 +324,24 @@ extern "C" {
 #define BRL_CMD_GUI_ITEM_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_ITEM_NEXT)
 /** move to the last item in the screen area */
 #define BRL_CMD_GUI_ITEM_LAST (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI_ITEM_LAST)
+/** decrease speaking pitch */
+#define BRL_CMD_SAY_LOWER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_LOWER)
+/** increase speaking pitch */
+#define BRL_CMD_SAY_HIGHER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_HIGHER)
+/** speak from top of screen through bottom of screen */
+#define BRL_CMD_SAY_ALL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_ALL)
+/** set contracted/computer braille */
+#define BRL_CMD_CONTRACTED (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTRACTED)
+/** set six/eight dot computer braille */
+#define BRL_CMD_COMPBRL6 (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COMPBRL6)
+/** reset preferences to defaults */
+#define BRL_CMD_PREFRESET (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PREFRESET)
+/** set autospeak empty line on/off */
+#define BRL_CMD_ASPK_EMP_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_EMP_LINE)
+/** cycle speech punctuation level */
+#define BRL_CMD_SPK_PUNCT_LEVEL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPK_PUNCT_LEVEL)
+/** insert the clipboard content before the screen cursor using the alternate paste mode */
+#define BRL_CMD_PASTE_ALTMODE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE_ALTMODE)
 /** bring screen cursor to character */
 #define BRL_BLK_ROUTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE)
 /** start new clipboard at character */
@@ -370,7 +388,7 @@ extern "C" {
 #define BRL_BLK_CLIP_APPEND (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_APPEND)
 /** deprecated definition of CLIP_APPEND - append characters to clipboard */
 #define BRL_BLK_APNDCHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_APNDCHARS)
-/** insert clipboard history entry after screen cursor */
+/** insert a clipboard history entry before the screen cursor */
 #define BRL_BLK_PASTE_HISTORY (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE_HISTORY)
 /** set text table */
 #define BRL_BLK_SET_TEXT_TABLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_TEXT_TABLE)
@@ -390,6 +408,10 @@ extern "C" {
 #define BRL_BLK_TXTSEL_START (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_START)
 /** set text selection */
 #define BRL_BLK_TXTSEL_SET (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_SET)
+/** bring speech cursor to character */
+#define BRL_BLK_ROUTE_SPEECH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE_SPEECH)
+/** insert a clipboard history entry before the screen cursor using the alternate paste mode */
+#define BRL_BLK_PASTE_HISTORY_ALTMODE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE_HISTORY_ALTMODE)
 /** bind to specific virtual terminal */
 #define BRL_BLK_SELECTVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SELECTVT)
 /** render an alert */
@@ -408,6 +430,10 @@ extern "C" {
 #define BRL_BLK_CONTEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTEXT)
 /** current reading location */
 #define BRL_BLK_TOUCH_AT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOUCH_AT)
+/** execute command macro */
+#define BRL_BLK_MACRO (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MACRO)
+/** run host command */
+#define BRL_BLK_HOSTCMD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOSTCMD)
 /** enter key */
 #define BRL_KEY_ENTER (BRLAPI_KEY_SYM_LINEFEED & 0XFF)
 /** tab key */
@@ -462,6 +488,10 @@ extern "C" {
 #define BRL_FLG_INPUT_ALTGR BRLAPI_KEY_FLG_INPUT_ALTGR
 /** gui (windows) key pressed */
 #define BRL_FLG_INPUT_GUI BRLAPI_KEY_FLG_INPUT_GUI
+/** prefix with escape */
+#define BRL_FLG_INPUT_ESCAPED BRLAPI_KEY_FLG_INPUT_ESCAPED
+/** capslock key pressed */
+#define BRL_FLG_INPUT_CAPSLOCK BRLAPI_KEY_FLG_INPUT_CAPSLOCK
 /** it is a release scan code */
 #define BRL_FLG_KBD_RELEASE BRLAPI_KEY_FLG_KBD_RELEASE
 /** it is an emulation 0 scan code */
